if [ -z ${CONDA_BUILD+x} ]; then
    source /opt/concourse/worker/volumes/live/c4c8e847-14bf-4ace-577c-9cf03fcb82a1/volume/pymongo_1620214110944/work/build_env_setup.sh
fi
python setup.py install --single-version-externally-managed --record=record.txt